@@ -5,7 +5,7 @@
 #' @param x A stanreg model.
 #' @param CI Credible interval bounds.
 #' @param index Index of effect existence to report. Can be 'overlap' or 'ROPE'.
-#' @param ROPE_bounds Bounds ot the ROPE. If NULL and effsize is TRUE, than the ROPE.
+#' @param ROPE_bounds Bounds of the ROPE. If NULL and effsize is TRUE, than the ROPE.
 #' will have default values c(-0.1, 0.1) and computed on the standardized posteriors.
 #' @param effsize Compute Effect Sizes according to Cohen (1988). For linear models only.
 #' @param effsize_rules Grid for effect size interpretation. See \link[=interpret_d]{interpret_d}.
@@ -25,31 +25,33 @@
 #' \dontrun{
 #' library(psycho)
 #' library(rstanarm)
-#'
+#' 
 #' data <- attitude
-#' fit <- rstanarm::stan_glm(rating ~ advance + privileges, data=data)
-#'
-#' results <- analyze(fit, effsize=TRUE)
+#' fit <- rstanarm::stan_glm(rating ~ advance + privileges, data = data)
+#' 
+#' results <- analyze(fit, effsize = TRUE)
 #' summary(results)
 #' print(results)
 #' plot(results)
-#'
-#'
-#' fit <- rstanarm::stan_glmer(Sepal.Length ~ Sepal.Width + (1|Species), data=iris)
+#' 
+#' 
+#' fit <- rstanarm::stan_lmer(Sepal.Length ~ Sepal.Width + (1 | Species), data = iris)
 #' results <- analyze(fit)
 #' summary(results)
-#'
+#' 
 #' fit <- rstanarm::stan_glm(Sex ~ Adjusting,
-#'     data=psycho::affective, family="binomial")
+#'   data = psycho::affective, family = "binomial"
+#' )
 #' results <- analyze(fit)
 #' summary(results)
-#'
-#' fit <- rstanarm::stan_glmer(Sex ~ Adjusting + (1|Salary),
-#'     data=psycho::affective, family="binomial")
+#' 
+#' fit <- rstanarm::stan_glmer(Sex ~ Adjusting + (1 | Salary),
+#'   data = psycho::affective, family = "binomial"
+#' )
 #' results <- analyze(fit)
 #' summary(results)
 #' }
-#'
+#' 
 #' @author \href{https://dominiquemakowski.github.io/}{Dominique Makowski}
 #'
 #' @seealso
@@ -66,7 +68,7 @@
 #' @importFrom broom tidy
 #' @importFrom stringr str_squish str_replace
 #' @export
-analyze.stanreg <- function(x, CI=90, index="overlap", ROPE_bounds=NULL, effsize=FALSE, effsize_rules="cohen1988", ...) {
+analyze.stanreg <- function(x, CI = 90, index = "overlap", ROPE_bounds = NULL, effsize = FALSE, effsize_rules = "cohen1988", ...) {
   fit <- x
 
   # Info --------------------------------------------------------------------
@@ -169,8 +171,8 @@ analyze.stanreg <- function(x, CI=90, index="overlap", ROPE_bounds=NULL, effsize
         effsize = effsize,
         effsize_rules = effsize_rules,
         fit = fit,
-        index=index,
-        ROPE_bounds=ROPE_bounds
+        index = index,
+        ROPE_bounds = ROPE_bounds
       )
     }
   }
@@ -190,6 +192,7 @@ analyze.stanreg <- function(x, CI=90, index="overlap", ROPE_bounds=NULL, effsize
         Median_std = values$effects[[varname]]$std_median,
         MAD_std = values$effects[[varname]]$std_mad,
         MPE = values$effects[[varname]]$MPE,
+        ROPE = values$effects[[varname]]$ROPE,
         Overlap = values$effects[[varname]]$overlap
       )
     )
@@ -199,6 +202,12 @@ analyze.stanreg <- function(x, CI=90, index="overlap", ROPE_bounds=NULL, effsize
     summary <- select_(summary, "-Median_std", "-MAD_std")
   }
 
+  if (index == "ROPE") {
+    summary <- select_(summary, "-Overlap")
+  } else {
+    summary <- select_(summary, "-ROPE")
+  }
+
   # Text --------------------------------------------------------------------
   # -------------------------------------------------------------------------
   # Model
@@ -337,7 +346,7 @@ analyze.stanreg <- function(x, CI=90, index="overlap", ROPE_bounds=NULL, effsize
 
 
 #' @keywords internal
-.get_info_priors <- function(varname, info_priors, predictors=NULL) {
+.get_info_priors <- function(varname, info_priors, predictors = NULL) {
   # Prior
   # TBD: this doesn't work with categorical predictors :(
   values <- list()
@@ -373,7 +382,7 @@ analyze.stanreg <- function(x, CI=90, index="overlap", ROPE_bounds=NULL, effsize
 
 
 #' @keywords internal
-.process_R2 <- function(varname, posteriors, info_priors, R2.adj=NULL, CI=90, effsize=FALSE) {
+.process_R2 <- function(varname, posteriors, info_priors, R2.adj = NULL, CI = 90, effsize = FALSE) {
   values <- .get_info_priors(varname, info_priors)
   posterior <- posteriors[, varname]
 
@@ -388,6 +397,7 @@ analyze.stanreg <- function(x, CI=90, index="overlap", ROPE_bounds=NULL, effsize
   values$MPE <- NA
   values$MPE_values <- NA
   values$overlap <- NA
+  values$ROPE <- NA
   values$adjusted_r_squared <- R2.adj
 
   # Text
@@ -450,7 +460,7 @@ analyze.stanreg <- function(x, CI=90, index="overlap", ROPE_bounds=NULL, effsize
 
 
 #' @keywords internal
-.process_intercept <- function(varname, posteriors, info_priors, predictors, CI=90, effsize=FALSE) {
+.process_intercept <- function(varname, posteriors, info_priors, predictors, CI = 90, effsize = FALSE) {
   values <- .get_info_priors(varname, info_priors, predictors)
   posterior <- posteriors[, varname]
 
@@ -465,6 +475,7 @@ analyze.stanreg <- function(x, CI=90, index="overlap", ROPE_bounds=NULL, effsize
   values$MPE <- NA
   values$MPE_values <- NA
   values$overlap <- NA
+  values$ROPE <- NA
 
 
 
@@ -518,13 +529,12 @@ analyze.stanreg <- function(x, CI=90, index="overlap", ROPE_bounds=NULL, effsize
                             posteriors_std,
                             info_priors,
                             predictors,
-                            CI=90,
-                            effsize=FALSE,
-                            effsize_rules=FALSE,
+                            CI = 90,
+                            effsize = FALSE,
+                            effsize_rules = FALSE,
                             fit,
-                            index="overlap",
-                            ROPE_bounds=NULL) {
-
+                            index = "overlap",
+                            ROPE_bounds = NULL) {
   values <- .get_info_priors(varname, info_priors, predictors)
   posterior <- posteriors[, varname]
 
@@ -550,42 +560,54 @@ analyze.stanreg <- function(x, CI=90, index="overlap", ROPE_bounds=NULL, effsize
     )
   )
 
-  if(!is.null(ROPE_bounds)){
-    rope <- rope(posterior, bounds=ROPE_bounds)
+  if (!is.null(ROPE_bounds)) {
+    rope <- rope(posterior, bounds = ROPE_bounds)
     values$ROPE_decision <- rope$rope_decision
     values$ROPE <- rope$rope_probability
+  } else {
+    values$ROPE <- NA
+    values$ROPE_decision <- NA
   }
 
-  if(index == "overlap"){
-    index <- paste0("Overlap = ",
-                    format_digit(values$overlap, null_treshold = 0.01),
-                    "%).")
-  } else if(index == "ROPE"){
-    if(!is.null(ROPE_bounds)){
-      index <- paste0("ROPE = ",
-                      format_digit(values$ROPE, null_treshold = 0.001),
-                      ").")
-    } else{
-      if(effsize == TRUE){
-        rope <- rope(posteriors_std[, varname], bounds=c(-0.1, 0.1))
+  if (index == "overlap") {
+    index <- paste0(
+      "Overlap = ",
+      format_digit(values$overlap, null_treshold = 0.01),
+      "%)."
+    )
+  } else if (index == "ROPE") {
+    if (!is.null(ROPE_bounds)) {
+      index <- paste0(
+        "ROPE = ",
+        format_digit(values$ROPE, null_treshold = 0.001),
+        ")."
+      )
+    } else {
+      if (effsize == TRUE) {
+        rope <- rope(posteriors_std[, varname], bounds = c(-0.1, 0.1))
         values$ROPE_decision <- rope$rope_decision
         values$ROPE <- rope$rope_probability
-        index <- paste0("ROPE = ",
-                        format_digit(values$ROPE, null_treshold = 0.001),
-                        ").")
-      } else{
+        index <- paste0(
+          "ROPE = ",
+          format_digit(values$ROPE, null_treshold = 0.001),
+          ")."
+        )
+      } else {
         warning("you need to specify ROPE_bounds (e.g. 'c(-0.1, 0.1)'). Computing overlap instead.")
-        index <- paste0("Overlap = ",
-                        format_digit(values$overlap, null_treshold = 0.01),
-                        "%).")
+        index <- paste0(
+          "Overlap = ",
+          format_digit(values$overlap, null_treshold = 0.01),
+          "%)."
+        )
       }
     }
-
-  } else{
+  } else {
     warning("Parameter 'index' should be 'overlap' or 'ROPE'. Computing overlap.")
-    index <- paste0("Overlap = ",
-                    format_digit(values$overlap, null_treshold = 0.01),
-                    "%).")
+    index <- paste0(
+      "Overlap = ",
+      format_digit(values$overlap, null_treshold = 0.01),
+      "%)."
+    )
   }
 
 
