@@ -77,14 +77,15 @@ format_string <- function(x, fmt, ...) {
 
 #' Format p values.
 #'
-#' @param pvalues P values (scalar or vector).
-#' @param stars Add stars.
+#' @param pvalues p values (scalar or vector).
+#' @param stars Add significance stars.
+#' @param stars_only Return only significance stars.
 #'
 #' @author \href{https://dominiquemakowski.github.io/}{Dominique Makowski}
 #'
 #' @importFrom stringr str_remove_all
 #' @export
-format_p <- function(pvalues, stars=TRUE) {
+format_p <- function(pvalues, stars = TRUE, stars_only=FALSE) {
   p <- ifelse(pvalues < 0.001, "< .001***",
     ifelse(pvalues < 0.01, "< .01**",
       ifelse(pvalues < 0.05, "< .05*",
@@ -95,8 +96,12 @@ format_p <- function(pvalues, stars=TRUE) {
     )
   )
 
-  if (stars == FALSE) {
-    p <- stringr::str_remove_all(p, "\\*")
+  if (stars_only == TRUE) {
+    p <- stringr::str_remove_all(p, "[^\\*]")
+  } else {
+    if (stars == FALSE) {
+      p <- stringr::str_remove_all(p, "\\*")
+    }
   }
 
   return(p)
@@ -121,12 +126,10 @@ format_p <- function(pvalues, stars=TRUE) {
 #' library(psycho)
 #' library(lme4)
 #'
-#' fit <- lme4::glmer(vs ~ wt + (1|gear), data=mtcars, family="binomial")
-#' fit <- lm(hp ~ wt, data=mtcars)
+#' fit <- lme4::glmer(vs ~ wt + (1 | gear), data = mtcars, family = "binomial")
+#' fit <- lm(hp ~ wt, data = mtcars)
 #'
 #' format_formula(get_formula(fit))
-#'
-#'
 #' @author \href{https://dominiquemakowski.github.io/}{Dominique Makowski}
 #'
 #' @export
