@@ -28,13 +28,12 @@ get_R2 <- function(fit, ...) {
 #' @examples
 #' \dontrun{
 #' library(psycho)
-#'
-#' fit <- lm(Tolerating ~ Adjusting, data=psycho::affective)
-#'
+#' 
+#' fit <- lm(Tolerating ~ Adjusting, data = psycho::affective)
+#' 
 #' get_R2(fit)
-#'
 #' }
-#'
+#' 
 #' @author \href{https://dominiquemakowski.github.io/}{Dominique Makowski}
 #' @export
 get_R2.lm <- function(fit, ...) {
@@ -58,18 +57,17 @@ get_R2.lm <- function(fit, ...) {
 #' @examples
 #' \dontrun{
 #' library(psycho)
-#'
-#' fit <- glm(vs ~ wt, data=mtcars, family="binomial")
-#' fit <- glm(Sex ~ Adjusting, data=psycho::affective, family="binomial")
-#'
+#' 
+#' fit <- glm(vs ~ wt, data = mtcars, family = "binomial")
+#' fit <- glm(Sex ~ Adjusting, data = psycho::affective, family = "binomial")
+#' 
 #' get_R2(fit)
-#'
 #' }
-#'
+#' 
 #' @author \href{https://dominiquemakowski.github.io/}{Dominique Makowski}
 #'
 #' @export
-get_R2.glm <- function(fit, method="nakagawa", ...) {
+get_R2.glm <- function(fit, method = "nakagawa", ...) {
   if (method == "nakagawa") {
     R2 <- as.numeric(R2_nakagawa(fit)$R2m)
   } else if (method == "tjur") {
@@ -95,19 +93,18 @@ get_R2.glm <- function(fit, method="nakagawa", ...) {
 #' \dontrun{
 #' library(psycho)
 #' library(rstanarm)
-#'
-#' fit <- rstanarm::stan_glm(Adjusting ~ Tolerating, data=psycho::affective)
-#'
+#' 
+#' fit <- rstanarm::stan_glm(Adjusting ~ Tolerating, data = psycho::affective)
+#' 
 #' get_R2(fit)
-#'
 #' }
-#'
+#' 
 #' @author \href{https://dominiquemakowski.github.io/}{Dominique Makowski}
 #'
 #' @seealso \link[=bayes_R2.stanreg]{"bayes_R2.stanreg"}
 #'
 #' @export
-get_R2.stanreg <- function(fit, silent=FALSE, ...) {
+get_R2.stanreg <- function(fit, silent = FALSE, ...) {
   tryCatch({
     R2 <- rstanarm::bayes_R2(fit)
   }, error = function(e) {
@@ -149,14 +146,17 @@ get_R2.stanreg <- function(fit, silent=FALSE, ...) {
 #' @examples
 #' \dontrun{
 #' library(psycho)
-#'
-#' fit <- lmerTest::lmer(Tolerating ~ Adjusting + (1|Sex), data=psycho::affective)
-#' fit <- lme4::glmer(Sex ~ Adjusting + (1|Salary), data=na.omit(psycho::affective), family="binomial")
-#'
+#' 
+#' fit <- lmerTest::lmer(Tolerating ~ Adjusting + (1 | Sex),
+#'   data = psycho::affective
+#' )
+#' fit <- lme4::glmer(Sex ~ Adjusting + (1 | Salary),
+#'   data = na.omit(psycho::affective), family = "binomial"
+#' )
+#' 
 #' get_R2(fit)
-#'
 #' }
-#'
+#' 
 #' @author \href{https://dominiquemakowski.github.io/}{Dominique Makowski}
 #' @export
 get_R2.merMod <- function(fit, ...) {
@@ -177,13 +177,12 @@ get_R2.merMod <- function(fit, ...) {
 #' @examples
 #' \dontrun{
 #' library(psycho)
-#'
-#' fit <- lmerTest::lmer(Sepal.Length ~ Sepal.Width + (1|Species), data=iris)
-#'
+#' 
+#' fit <- lmerTest::lmer(Sepal.Length ~ Sepal.Width + (1 | Species), data = iris)
+#' 
 #' R2_nakagawa(fit)
-#'
 #' }
-#'
+#' 
 #' @author \href{https://dominiquemakowski.github.io/}{Dominique Makowski}
 #'
 #' @references
@@ -212,14 +211,13 @@ R2_nakagawa <- function(fit) {
 #' \dontrun{
 #' library(psycho)
 #' library(rstanarm)
-#'
+#' 
 #' data <- attitude
-#' fit <- rstanarm::stan_glm(rating ~ advance + privileges, data=data)
-#'
+#' fit <- rstanarm::stan_glm(rating ~ advance + privileges, data = data)
+#' 
 #' R2_LOO_Adjusted(fit)
-#'
 #' }
-#'
+#' 
 #' @author \href{https://github.com/strengejacke}{Daniel Luedecke}
 #'
 #' @import rstantools
@@ -244,6 +242,10 @@ R2_LOO_Adjusted <- function(fit) {
 
   psis_object <- loo::psis(log_ratios = -ll, r_eff = r_eff)
   ypredloo <- loo::E_loo(ypred, psis_object, log_ratios = -ll)$value
+  if (length(ypredloo) != length(y)) {
+    warning("Something went wrong in the Loo-adjusted R2 computation.")
+    return(NA)
+  }
   eloo <- ypredloo - y
 
   adj_r_squared <- 1 - stats::var(eloo) / stats::var(y)
@@ -253,9 +255,6 @@ R2_LOO_Adjusted <- function(fit) {
 
 
 
-
-
-
 #' Tjur's (2009) coefficient of determination.
 #'
 #' Computes Tjur's (2009) coefficient of determination.
@@ -265,11 +264,9 @@ R2_LOO_Adjusted <- function(fit) {
 #' @examples
 #' library(psycho)
 #' library(lme4)
-#'
-#' fit <- lme4::glmer(vs ~ wt + (1|gear), data=mtcars, family="binomial")
+#' 
+#' fit <- lme4::glmer(vs ~ wt + (1 | gear), data = mtcars, family = "binomial")
 #' R2_tjur(fit)
-#'
-#'
 #' @author \href{https://github.com/strengejacke}{Daniel Lüdecke}
 #'
 #' @import dplyr
