@@ -11,6 +11,7 @@
 #' @param posterior_predict Posterior draws of the outcome instead of the link function (i.e., the regression "line").
 #' @param seed An optional seed to use.
 #' @param transform If posterior_predict is False, should the linear predictor be transformed using the inverse-link function? The default is FALSE, in which case the untransformed linear predictor is returned.
+#' @param re.form If object contains group-level parameters, a formula indicating which group-level parameters to condition on when making predictions. re.form is specified in the same form as for predict.merMod. NULL indicates that all estimated group-level parameters are conditioned on. To refrain from conditioning on any group-level parameters, specify NA or ~0. The newdata argument may include new levels of the grouping factors that were specified when the model was estimated, in which case the resulting posterior predictions marginalize over the relevant variables (see \link[rstanarm]{posterior_predict.stanreg}). If "default", then will ne NULL if the random are present in the data, and NA if not.
 #' @param ... Arguments passed to or from other methods.
 #'
 #'
@@ -22,29 +23,34 @@
 #' library(psycho)
 #' library(ggplot2)
 #' require(rstanarm)
-#'
-#' fit <- rstanarm::stan_glm(Tolerating ~ Adjusting, data=affective)
-#'
+#' 
+#' fit <- rstanarm::stan_glm(Tolerating ~ Adjusting, data = affective)
+#' 
 #' refgrid <- psycho::refdata(affective, "Adjusting")
-#' predicted <- get_predicted(fit, newdata=refgrid)
-#'
-#' ggplot(predicted, aes(x=Adjusting, y=Tolerating_Median)) +
+#' predicted <- get_predicted(fit, newdata = refgrid)
+#' 
+#' ggplot(predicted, aes(x = Adjusting, y = Tolerating_Median)) +
 #'   geom_line() +
-#'   geom_ribbon(aes(ymin=Tolerating_CI_5,
-#'                   ymax=Tolerating_CI_95),
-#'                   alpha=0.1)
-#'
-#' fit <- rstanarm::stan_glm(Sex ~ Adjusting, data=affective, family="binomial")
-#'
+#'   geom_ribbon(aes(
+#'     ymin = Tolerating_CI_5,
+#'     ymax = Tolerating_CI_95
+#'   ),
+#'   alpha = 0.1
+#'   )
+#' 
+#' fit <- rstanarm::stan_glm(Sex ~ Adjusting, data = affective, family = "binomial")
+#' 
 #' refgrid <- psycho::refdata(affective, "Adjusting")
-#' predicted <- get_predicted(fit, newdata=refgrid)
-#'
-#' ggplot(predicted, aes(x=Adjusting, y=Sex_Median)) +
+#' predicted <- get_predicted(fit, newdata = refgrid)
+#' 
+#' ggplot(predicted, aes(x = Adjusting, y = Sex_Median)) +
 #'   geom_line() +
-#'   geom_ribbon(aes(ymin=Sex_CI_5,
-#'                   ymax=Sex_CI_95),
-#'                   alpha=0.1)
-#'
+#'   geom_ribbon(aes(
+#'     ymin = Sex_CI_5,
+#'     ymax = Sex_CI_95
+#'   ),
+#'   alpha = 0.1
+#'   )
 #' }
 #' @author \href{https://dominiquemakowski.github.io/}{Dominique Makowski}
 #'
@@ -53,7 +59,7 @@
 #' @importFrom dplyr bind_cols
 #' @importFrom tibble rownames_to_column
 #' @export
-get_predicted.stanreg <- function(fit, newdata="model", prob=0.9, odds_to_probs=TRUE, keep_iterations=FALSE, draws=NULL, posterior_predict=FALSE, seed=NULL, transform=FALSE, ...) {
+get_predicted.stanreg <- function(fit, newdata = "model", prob = 0.9, odds_to_probs = TRUE, keep_iterations = FALSE, draws = NULL, posterior_predict = FALSE, seed = NULL, transform = FALSE, re.form = "default", ...) {
 
   # Extract names
   predictors <- all.vars(as.formula(fit$formula))
@@ -66,14 +72,6 @@ get_predicted.stanreg <- function(fit, newdata="model", prob=0.9, odds_to_probs=
     newdata[".wgt."] <- NULL
   }
 
-  # Deal with potential random
-  re.form <- NULL
-  if (!is.null(newdata)) {
-    if (!is.character(newdata) & is.mixed(fit)) {
-      re.form <- NA
-    }
-  }
-
   # Set newdata to actual data
   original_data <- FALSE
   if (!is.null(newdata)) {
@@ -86,9 +84,23 @@ get_predicted.stanreg <- function(fit, newdata="model", prob=0.9, odds_to_probs=
     }
   }
 
+  # Deal with potential random
+  if (!is.na(re.form)) {
+    if (re.form == "default") {
+      if (is.mixed(fit)) {
+        # Check if all predictors are in variables
+        if (all(get_info(fit)$predictors %in% names(newdata))) {
+          re.form <- NULL
+        } else {
+          re.form <- NA
+        }
+      }
+    }
+  }
+
   # Generate draws -------------------------------------------------------
   if (posterior_predict == FALSE) {
-    posterior <- rstanarm::posterior_linpred(fit, newdata = newdata, re.form = re.form, seed = seed, draws = draws, transform=transform)
+    posterior <- rstanarm::posterior_linpred(fit, newdata = newdata, re.form = re.form, seed = seed, draws = draws, transform = transform)
   } else {
     posterior <- rstanarm::posterior_predict(fit, newdata = newdata, re.form = re.form, seed = seed, draws = draws)
   }
